summaryrefslogtreecommitdiff
path: root/sources/prefs/VSPrefsRestriction.java
diff options
context:
space:
mode:
Diffstat (limited to 'sources/prefs/VSPrefsRestriction.java')
-rw-r--r--sources/prefs/VSPrefsRestriction.java6
1 files changed, 3 insertions, 3 deletions
diff --git a/sources/prefs/VSPrefsRestriction.java b/sources/prefs/VSPrefsRestriction.java
index 5a716bd..f66246c 100644
--- a/sources/prefs/VSPrefsRestriction.java
+++ b/sources/prefs/VSPrefsRestriction.java
@@ -33,9 +33,9 @@ public class VSPrefsRestriction implements Serializable {
private static final long serialVersionUID = 1L;
/**
* The class VSIntegerPrefRestriction.
*/
- public static class VSIntegerPrefRestriction extends VSPrefsRestriction {
+ public static class VSIntegerPrefsRestriction extends VSPrefsRestriction {
private static final long serialVersionUID = 1L;
/** The min value. */
private int minValue;
@@ -49,7 +49,7 @@ public class VSPrefsRestriction implements Serializable {
* @param minValue the min value
* @param maxValue the max value
*/
- public VSIntegerPrefRestriction(int minValue, int maxValue) {
+ public VSIntegerPrefsRestriction(int minValue, int maxValue) {
this.minValue = minValue;
this.maxValue = maxValue;
}
@@ -33,9 +33,9 @@ public class VSPrefsRestriction implements Serializable {
private static final long serialVersionUID = 1L;
/**
- * The class VSIntegerPrefRestriction.
+ * The class VSIntegerPrefsRestriction.
*/